powered by
This function evaluates the transformation of the original data matrix for t from -pi to pi, and uses matplot to draw the curves.
t
-pi
pi
matplot
andrews_curve( x, n = 101, type = "l", lty = 1, lwd = 1, pch = NA, xlab = "t", ylab = "f(t)", ... )
a matrix of coefficients for each observation at different t values
a data frame or matrix
number of x-axis values at which f(t) is evaluated
passed to matplot
Yihui Xie <https://yihui.org>
https://en.wikipedia.org/wiki/Andrews_plot
andrews_curve(iris[, -5], col = as.integer(iris[, 5]))
Run the code above in your browser using DataLab