powered by
Calculate the coordinates of a heart shape and draw it with a polygon.
heart_curve(n = 101, ...)
the number of points to use when calculating the coordinates of the heart shape
other arguments to be passed to polygon, e.g. the color of the polygon (usually red)
polygon
Yihui Xie <https://yihui.org>
heart_curve() heart_curve(col = "red") heart_curve(col = "pink", border = "red")
Run the code above in your browser using DataLab